# Projen Types

Additional [projen](https://github.com/projen/projen.git) project types

<!-- github action status and package version badges -->

[![release](https://github.com/mnoumanshahzad/projen-types/actions/workflows/release.yml/badge.svg)](https://github.com/mnoumanshahzad/projen-types/actions/workflows/release.yml)
[![GitHub version](https://badge.fury.io/gh/mnoumanshahzad%2Fprojen-types.svg)](https://badge.fury.io/gh/mnoumanshahzad%2Fprojen-types)
[![npm version](https://badge.fury.io/js/projen-types.svg)](https://badge.fury.io/js/projen-types)
[![PyPI version](https://badge.fury.io/py/projen-types.svg)](https://badge.fury.io/py/projen-types)

## Getting Started

To create a new project, run the following command and follow the instructions:

```bash
  $ mkdir my-project
  $ cd my-project
  $ npx projen new --from projen-types <PROJECT-TYPE>
  🤖 Synthesizing project...
  ...
```

## Project types

* mns-awscdk-app-py - AWS CDK app in Python
* mns-awscdk-app-ts - AWS CDK app in Typescript
